@@ -237,7 +237,7 @@ def push_csv2tog(job_id: int, file_path: str, access_token: str):
     data_frame = pd.read_csv(file_path)
     dataset = []
     for _, row in tqdm(data_frame.iterrows(), total=len(data_frame)):
-        if row["alternatives"].isnull():
+        if pd.isna(row["alternatives"]):
             alternatives = []
         else:
             alternatives = json.loads(row["alternatives"])
